PALM-meteo: palmmeteo_stdplugins.setup_staticdriver.Building Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
palmmeteo_stdplugins.setup_staticdriver.Building Class Reference

## Public Member Functions
| __init__ (self, bid, bids)

## Public Attributes
| id
| x0
| x1
| y0
| y1
| slices
| mask

## Constructor & Destructor Documentation

## ◆ __init__()

palmmeteo_stdplugins.setup_staticdriver.Building.__init__ | ( |  | self,
|  |  | bid,
|  |  | bids
| ) |  |

## Member Data Documentation

## ◆ id

palmmeteo_stdplugins.setup_staticdriver.Building.id

## ◆ mask

palmmeteo_stdplugins.setup_staticdriver.Building.mask

## ◆ slices

palmmeteo_stdplugins.setup_staticdriver.Building.slices

## ◆ x0

palmmeteo_stdplugins.setup_staticdriver.Building.x0

## ◆ x1

palmmeteo_stdplugins.setup_staticdriver.Building.x1

## ◆ y0

palmmeteo_stdplugins.setup_staticdriver.Building.y0

## ◆ y1

palmmeteo_stdplugins.setup_staticdriver.Building.y1

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/setup_staticdriver.py